read_nested

Function read_nested 

pub fn read_nested(
    encoded_cbor: &[u8],
    max_nest: Option<i8>,
) -> Result<Value, DecoderError>
Deserialize CBOR binary data to produce a single Value, expecting that there is no additional data. If max_nest is Some(max), then nested structures are only supported up to the given limit (returning DecoderError::TooMuchNesting if the limit is hit).