Constants

Struct Constants 

pub struct Constants {}
Constant values required for CBOR encoding.

Implementations

Source

impl Constants

pub const MAJOR_TYPE_BIT_SHIFT: u8 = 5

Number of bits used to shift left the major type of a CBOR type byte.

pub const ADDITIONAL_INFORMATION_MASK: u8 = 0x1F

Mask to retrieve the additional information held in a CBOR type bytes, ignoring the major type.

pub const ADDITIONAL_INFORMATION_MAX_INT: u8 = 23

Additional information value that indicates the largest inline value.

pub const ADDITIONAL_INFORMATION_1_BYTE: u8 = 24

Additional information value indicating that a 1-byte length follows.

pub const ADDITIONAL_INFORMATION_2_BYTES: u8 = 25

Additional information value indicating that a 2-byte length follows.

pub const ADDITIONAL_INFORMATION_4_BYTES: u8 = 26

Additional information value indicating that a 4-byte length follows.

pub const ADDITIONAL_INFORMATION_8_BYTES: u8 = 27

Additional information value indicating that an 8-byte length follows.