pub struct Constants {}Expand description
Constant values required for CBOR encoding.
Implementations
Sourceimpl Constants
impl Constants
Sourcepub const MAJOR_TYPE_BIT_SHIFT: u8 = 5
pub const MAJOR_TYPE_BIT_SHIFT: u8 = 5
Number of bits used to shift left the major type of a CBOR type byte.
Sourcepub const ADDITIONAL_INFORMATION_MASK: u8 = 0x1F
pub const ADDITIONAL_INFORMATION_MASK: u8 = 0x1F
Mask to retrieve the additional information held in a CBOR type bytes, ignoring the major type.
Sourcepub const ADDITIONAL_INFORMATION_MAX_INT: u8 = 23
pub const ADDITIONAL_INFORMATION_MAX_INT: u8 = 23
Additional information value that indicates the largest inline value.
Sourcepub const ADDITIONAL_INFORMATION_1_BYTE: u8 = 24
pub const ADDITIONAL_INFORMATION_1_BYTE: u8 = 24
Additional information value indicating that a 1-byte length follows.
Sourcepub const ADDITIONAL_INFORMATION_2_BYTES: u8 = 25
pub const ADDITIONAL_INFORMATION_2_BYTES: u8 = 25
Additional information value indicating that a 2-byte length follows.
Sourcepub const ADDITIONAL_INFORMATION_4_BYTES: u8 = 26
pub const ADDITIONAL_INFORMATION_4_BYTES: u8 = 26
Additional information value indicating that a 4-byte length follows.
Sourcepub const ADDITIONAL_INFORMATION_8_BYTES: u8 = 27
pub const ADDITIONAL_INFORMATION_8_BYTES: u8 = 27
Additional information value indicating that an 8-byte length follows.